Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ShardManager ¶
ShardManager determines if the current manager instance is responsible for a given resource
func NewShardManager ¶
func NewShardManager(shardID, totalShards int) *ShardManager
NewShardManager creates a new ShardManager
func (*ShardManager) IsResponsibleFor ¶
func (s *ShardManager) IsResponsibleFor(key string) bool
IsResponsibleFor returns true if the current shard is responsible for the given key
Click to show internal directories.
Click to hide internal directories.